/* 
    qasn1editor - MainArea - main dialog for qasn1editor
    Copyright(C) 2010 - Andrius da Costa Ribas

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QtGui>
//#include <QtCore/QDebug>
#include "MainArea.h"
#include "Asn1BerModel.h"
#include "Asn1BerParser.h"


MainArea::MainArea(QWidget *parent)
{
    setupUi(this); // this sets up GUI
    
    m_model = 0;
    m_node = 0;
    
    m_control = new SignalWrapper(this);
    
    m_control->setTagControl(edtTag);
    m_control->setConstructedControl(chkConstructed);
    m_control->setDefinedLengthControl(chkDefinedLength);
    m_control->setRawValueControl(edtRawVal);
    m_control->setRadioControls(radUniversal, radApplication, radContext, radPrivate);
    
    connect ( treeMain, SIGNAL(activated(QModelIndex )), m_control, SLOT(changeTree(QModelIndex )) );
    connect ( treeMain, SIGNAL(clicked(QModelIndex )), m_control, SLOT(changeTree(QModelIndex )) );
    connect ( treeMain, SIGNAL(pressed(QModelIndex )), m_control, SLOT(changeTree(QModelIndex )) );
    connect ( treeMain, SIGNAL(expanded(QModelIndex ) ), this, SLOT(updateSize() ) );
    connect ( actionOpen, SIGNAL(activated()), this, SLOT(openFile()) );
    connect ( actionAbout, SIGNAL(activated()), this, SLOT(about()) );
}

void MainArea::about() 
{
    QMessageBox::about(this,"About qasn1editor - Asn.1 BER Editor",
                "Copyright (c) 2010 - Andrius da Costa Ribas.\n"
                "See LICENSE file for copying info\n"
                "Thanks to Patrick Spendrin for all mentoring.\n");
}

void MainArea::openFile()
{
    QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"));
    
    if ( fileName == "" ) return;
    
    if ( m_model != 0 )
    {
        delete m_model;
    }
    if ( m_node != 0 )
    {
        delete m_node;
    }
    
    QFile file(fileName);
    setWindowTitle(QString("qasn1editor - %1").arg(fileName));
    file.open(QIODevice::ReadOnly);
    
    Asn1BerParser parser(&file);
    parser.enableProgressDialog();
    m_node = parser.parse();
    m_model = new Asn1BerModel(m_node, this);
    
    treeMain->setModel(m_model);
    m_control->setModel(m_model);
    
    m_control->setupControls();
    
    updateSize();
    
}

void MainArea::updateSize()
{
    treeMain->header()->setResizeMode(0, QHeaderView::ResizeToContents);
    treeMain->header()->setStretchLastSection(false);
}
#include "MainArea.moc"